//V-Slot Clip-On Endcap Covers with or without screws.
//This works with 2020, 2040, 2060, 2080, 4040 V-Slot & C-Beam
//By: David Bunch   11/30/2018
//
/* [Main Variables] */
//1. V-Slot Size(20,40,60 or 80)
L1 = 100;            //[20:2020,40:2040,60:2060,80:2080,100:CBeam,120:4040]

//2. Endcap Cover Type
Fit_Type = 0;       //[0:Endcap Only,1:Internal Channel Fit,2:External Fit,3:External & Internal]

//3. Add Externals on Ends
ExtEnd_ON = 0;      //[0:None On Ends,1:One End,2:Both Ends]

//4. Drill M5 Hole
M5_Hole_ON = 2;     //[0:No Hole,1:Center or Both Ends,2:All Holes]    

//5. Ghost V-Slot
V_ON = 1;             //[0:No V-Slot Shown, 1:Show V-Slot]

/* [Heights] */
//6. Height of Base
Base_Ht = 1;        //[.5:.5:8]

//7. Height of Connection
Ht = 11;            //[6:.5:20]

//8. Round Diameter at bottom of Cap
Rnd_OD = 3;        //[1:.5:12]

//9. Height of roundings
Rnd_Ht = 2.2;          //[[.5:.5:4]

//10. How Much to Add to Internal Bump Grip width
Bmp_Add = .25;      //[0:.125:1]

//11. Height of Bump Grip
Bmp_Ht = 2;         //[1:.25:4]

/* [Hole Variables] */
//12. M5 Diameter
M5_OD = 5.6;        //Diameter of M5 Hole

//13. M5 Head Diameter
M5_Hd_OD = 10.5;    //Diameter of M5 Head

//14. M5 Head height
M5_Hd_Ht = 4;     //Height of Recess for M5 Head (Set to 0 for NO Recess)

/* [Hidden] */

Clip_Base_Ht = 3.375;        //Internal Clip Base height
Clip_Connect_Ht = 3.75+2;   //Internal Height where it connects to side of alum.
Clip_Ht = Clip_Base_Ht+Clip_Connect_Ht+1.875;            //Total Clip Height

Rnd_Rad = Rnd_OD / 2.0;

//W1 = 20;            

L_Type = ((L1 / 10) / 2) - 1;       //20 = 0, 40 = 1, 60 = 2, 80 = 3

B_Ht = Base_Ht - Rnd_Ht;

M5_OD_Res = (round(((M5_OD * 3.14) / 4) / .5)*4);
Rnd_Res = (round(((Rnd_OD * 3.14) / 4) / .7)*4);

E1 = L_Type * 10;
Ext_Arr = [ [0], [-10,10], [-20,0,20], [-30,-10,10,30], [-30,-10,10,30], [-10,10] ];   //For External Connections
Int_Arr = [ [0], [0], [-10,10], [-20,0,20], [-20,0,20], [0] ];               //For Internal Connections

Hol_XArr =  [ [0], [-10,10], [-20,0,20], [-30,-10,10,30], [-30,-30,-10,10,30,30], [-10,10,-10,10] ];   //All Hole X Offsets
Hol_YArr = [ [0], [0,0],    [0,0,0],    [0,0,0,0],       [20,0,0,0,0,20],        [-10,-10,10,10] ];
//Hole Offsets when M5_Hole_ON = 1
//                    Y1 = Hol1Y[i];
Hol_XArr1 =  [ [0], [-10,10], [0], [-30,30], [-30,30], [-10,-10,10,10] ];
Hol_YArr1 = [ [0], [0,0],    [0], [0,0],    [0,0],    [-10,-10,10,10] ];
Wid_Arr = [20,20,20,20,40,40];

W1 = Wid_Arr[L_Type];   //Width of V-Slot, DO NOT CHANGE this
//Capture the nested arrays which is what is used with the for loops
Ext1 = Ext_Arr[L_Type];
Int1 = Int_Arr[L_Type];
HolX = Hol_XArr[L_Type];
HolX1 = Hol_XArr1[L_Type];
HolY = Hol_YArr[L_Type];
HolY1 = Hol_YArr1[L_Type];

echo(L1 = L1);
echo(W1 = W1);
echo(L_Type = L_Type);
echo(M5_OD_Res = M5_OD_Res);
echo(Rnd_Res = Rnd_Res);
echo("***** E1 = ",E1);
echo(Clip_Ht = Clip_Ht);
echo(HolY = HolY);
echo(HolY1 = HolY1);
module V_Slot(VS_Ht = 50)
{
    if (L_Type == 0)V_2020(VS_Ht);
    if (L_Type == 1)V_2040(VS_Ht);
    if (L_Type == 2)V_2060(VS_Ht);
    if (L_Type == 3)V_2080(VS_Ht);
    if (L_Type == 4)CB_4080(VS_Ht);
    if (L_Type == 5)V_4040(VS_Ht);
}
module V_2020(V_Ht = 10)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[10,4.64],[10,10],[4.64,10],[2.84,8.2],[5.5,8.2],
        [5.5,6.56],[2.84,3.9],[-2.84,3.9],[-5.5,6.56],[-5.5,8.2],
        [-2.84,8.2],[-4.64,10],[-10,10],[-10,4.64],[-8.2,2.84],
        [-8.2,5.5],[-6.56,5.5],[-3.9,2.84],[-3.9,-2.84],[-6.56,-5.5],
        [-8.2,-5.5],[-8.2,-2.84],[-10,-4.64],[-10,-10],[-4.64,-10],
        [-2.84,-8.2],[-5.5,-8.2],[-5.5,-6.56],[-2.84,-3.9],[2.84,-3.9],
        [5.5,-6.56],[5.5,-8.2],[2.84,-8.2],[4.64,-10],[10,-10],
        [10,-4.64],[8.2,-2.84],[8.2,-5.5],[6.56,-5.5],[3.9,-2.84],
        [3.9,2.84],[6.56,5.5],[8.2,5.5],[8.2,2.84]]);
        translate([0,0,-1])
        cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
    }
}
module V_2040(V_Ht = 10)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[14.64,-10],[20,-10],[20,-4.64],[18.2,-2.84],[18.2,-5.5],
        [16.56,-5.5],[13.9,-2.84],[13.9,2.84],[16.56,5.5],[18.2,5.5],
        [18.2,2.84],[20,4.64],[20,10],[14.64,10],[12.84,8.2],
        [15.5,8.2],[15.5,6.56],[12.84,3.9],[7.16,3.9],[4.5,6.56],
        [4.5,8.2],[7.16,8.2],[5.36,10],[-5.36,10],[-7.16,8.2],
        [-4.5,8.2],[-4.5,6.56],[-7.16,3.9],[-12.84,3.9],[-15.5,6.56],
        [-15.5,8.2],[-12.84,8.2],[-14.64,10],[-20,10],[-20,4.64],
        [-18.2,2.84],[-18.2,5.5],[-16.56,5.5],[-13.9,2.84],[-13.9,-2.84],
        [-16.56,-5.5],[-18.2,-5.5],[-18.2,-2.84],[-20,-4.64],[-20,-10],
        [-14.64,-10],[-12.84,-8.2],[-15.5,-8.2],[-15.5,-6.56],[-12.84,-3.9],
        [-7.16,-3.9],[-4.5,-6.56],[-4.5,-8.2],[-7.16,-8.2],[-5.36,-10],
        [5.36,-10],[7.16,-8.2],[4.5,-8.2],[4.5,-6.56],[7.16,-3.9],
        [12.84,-3.9],[15.5,-6.56],[15.5,-8.2],[12.84,-8.2],[14.64,-10]]);
        translate([0,0,-1])
        cylinder(d=4.2,h=V_Ht+2,center=false,$fn=12);
        for (x = [-10,10])
        {
            translate([x,0,-1])
            cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
        }
        for (m = [0,1])
        {
            mirror([m,0,0])
            translate([0,0,-1])
            linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
            [[-2.7,8.2],[2.7,8.2],[2.7,6.24],[6.1,2.84],[6.1,-2.84],
            [2.7,-6.24],[2.7,-8.2],[-2.7,-8.2],[-2.7,-6.24],[-6.1,-2.84],
            [-6.1,2.84],[-2.7,6.24]]);
        }
    }
}
module V_2060(V_Ht = 10)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[30,4.64],[30,10],[24.64,10],[22.84,8.2],[25.5,8.2],
        [25.5,6.56],[22.84,3.9],[17.16,3.9],[14.5,6.56],[14.5,8.2],
        [17.16,8.2],[15.36,10],[4.64,10],[2.84,8.2],[5.5,8.2],
        [5.5,6.56],[2.84,3.9],[-2.84,3.9],[-5.5,6.56],[-5.5,8.2],
        [-2.84,8.2],[-4.64,10],[-15.36,10],[-17.16,8.2],[-14.5,8.2],
        [-14.5,6.56],[-17.16,3.9],[-22.84,3.9],[-25.5,6.56],[-25.5,8.2],
        [-22.84,8.2],[-24.64,10],[-30,10],[-30,4.64],[-28.2,2.84],
        [-28.2,5.5],[-26.56,5.5],[-23.9,2.84],[-23.9,-2.84],[-26.56,-5.5],
        [-28.2,-5.5],[-28.2,-2.84],[-30,-4.64],[-30,-10],[-24.64,-10],
        [-22.84,-8.2],[-25.5,-8.2],[-25.5,-6.56],[-22.84,-3.9],[-17.16,-3.9],
        [-14.5,-6.56],[-14.5,-8.2],[-17.16,-8.2],[-15.36,-10],[-4.64,-10],
        [-2.84,-8.2],[-5.5,-8.2],[-5.5,-6.56],[-2.84,-3.9],[2.84,-3.9],
        [5.5,-6.56],[5.5,-8.2],[2.84,-8.2],[4.64,-10],[15.36,-10],
        [17.16,-8.2],[14.5,-8.2],[14.5,-6.56],[17.16,-3.9],[22.84,-3.9],
        [25.5,-6.56],[25.5,-8.2],[22.84,-8.2],[24.64,-10],[30,-10],
        [30,-4.64],[28.2,-2.84],[28.2,-5.5],[26.56,-5.5],[23.9,-2.84],
        [23.9,2.84],[26.56,5.5],[28.2,5.5],[28.2,2.84]]);
        for (x = [-20,0,20])
        {
            translate([x,0,-1])
            cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
        }
        for (x = [-10,10])
        {
            translate([x,0,-1])
            linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
            [[-2.7,8.2],[2.7,8.2],[2.7,6.24],[6.1,2.84],[6.1,-2.84],
            [2.7,-6.24],[2.7,-8.2],[-2.7,-8.2],[-2.7,-6.24],[-6.1,-2.84],
            [-6.1,2.84],[-2.7,6.24]]);
        }
    }
}
module V_2080(V_Ht = 10)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[40,4.64],[38.2,2.84],[38.2,5.5],[36.56,5.5],[33.9,2.84],
        [33.9,-2.84],[36.56,-5.5],[38.2,-5.5],[38.2,-2.84],[40,-4.64],
        [40,-10],[34.64,-10],[32.84,-8.2],[35.5,-8.2],[35.5,-6.56],
        [32.84,-3.9],[27.16,-3.9],[24.5,-6.56],[24.5,-8.2],[27.16,-8.2],
        [25.36,-10],[14.64,-10],[12.84,-8.2],[15.5,-8.2],[15.5,-6.56],
        [12.84,-3.9],[7.16,-3.9],[4.5,-6.56],[4.5,-8.2],[7.16,-8.2],
        [5.36,-10],[-5.36,-10],[-7.16,-8.2],[-4.5,-8.2],[-4.5,-6.56],
        [-7.16,-3.9],[-12.84,-3.9],[-15.5,-6.56],[-15.5,-8.2],[-12.84,-8.2],
        [-14.64,-10],[-25.36,-10],[-27.16,-8.2],[-24.5,-8.2],[-24.5,-6.56],
        [-27.16,-3.9],[-32.84,-3.9],[-35.5,-6.56],[-35.5,-8.2],[-32.84,-8.2],
        [-34.64,-10],[-40,-10],[-40,-4.64],[-38.2,-2.84],[-38.2,-5.5],
        [-36.56,-5.5],[-33.9,-2.84],[-33.9,2.84],[-36.56,5.5],[-38.2,5.5],
        [-38.2,2.84],[-40,4.64],[-40,10],[-34.64,10],[-32.84,8.2],
        [-35.5,8.2],[-35.5,6.56],[-32.84,3.9],[-27.16,3.9],[-24.5,6.56],
        [-24.5,8.2],[-27.16,8.2],[-25.36,10],[-14.64,10],[-12.84,8.2],
        [-15.5,8.2],[-15.5,6.56],[-12.84,3.9],[-7.16,3.9],[-4.5,6.56],
        [-4.5,8.2],[-7.16,8.2],[-5.36,10],[5.36,10],[7.16,8.2],
        [4.5,8.2],[4.5,6.56],[7.16,3.9],[12.84,3.9],[15.5,6.56],
        [15.5,8.2],[12.84,8.2],[14.64,10],[25.36,10],[27.16,8.2],
        [24.5,8.2],[24.5,6.56],[27.16,3.9],[32.84,3.9],[35.5,6.56],
        [35.5,8.2],[32.84,8.2],[34.64,10],[40,10]]);
        for (x = [-30,-10,10,30])
        {
            translate([x,0,-1])
            cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
        }
        for (x = [-20,0,20])
        {
            translate([x,0,-1])
            linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
            [[-2.7,8.2],[2.7,8.2],[2.7,6.24],[6.1,2.84],[6.1,-2.84],
            [2.7,-6.24],[2.7,-8.2],[-2.7,-8.2],[-2.7,-6.24],[-6.1,-2.84],
            [-6.1,2.84],[-2.7,6.24]]);
        }
    }
}
module CB_4080(V_Ht = 10)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[20,24.64],[20,30],[25.36,30],[27.16,28.2],[24.5,28.2],
        [24.5,26.56],[27.16,23.9],[32.84,23.9],[35.5,26.56],[35.5,28.2],
        [32.84,28.2],[34.64,30],[40,30],[40,24.64],[38.2,22.84],
        [38.2,25.5],[36.56,25.5],[33.9,22.84],[33.9,17.16],[36.56,14.5],
        [38.2,14.5],[38.2,17.16],[40,15.36],[40,4.64],[38.2,2.84],
        [38.2,5.5],[36.56,5.5],[33.9,2.84],[33.9,-2.84],[36.56,-5.5],
        [38.2,-5.5],[38.2,-2.84],[40,-4.64],[40,-10],[34.64,-10],
        [32.84,-8.2],[35.5,-8.2],[35.5,-6.56],[32.84,-3.9],[27.16,-3.9],
        [24.5,-6.56],[24.5,-8.2],[27.16,-8.2],[25.36,-10],[14.64,-10],
        [12.84,-8.2],[15.5,-8.2],[15.5,-6.56],[12.84,-3.9],[7.16,-3.9],
        [4.5,-6.56],[4.5,-8.2],[7.16,-8.2],[5.36,-10],[-5.36,-10],
        [-7.16,-8.2],[-4.5,-8.2],[-4.5,-6.56],[-7.16,-3.9],[-12.84,-3.9],
        [-15.5,-6.56],[-15.5,-8.2],[-12.84,-8.2],[-14.64,-10],[-25.36,-10],
        [-27.16,-8.2],[-24.5,-8.2],[-24.5,-6.56],[-27.16,-3.9],[-32.84,-3.9],
        [-35.5,-6.56],[-35.5,-8.2],[-32.84,-8.2],[-34.64,-10],[-40,-10],
        [-40,-4.64],[-38.2,-2.84],[-38.2,-5.5],[-36.56,-5.5],[-33.9,-2.84],
        [-33.9,2.84],[-36.56,5.5],[-38.2,5.5],[-38.2,2.84],[-40,4.64],
        [-40,15.36],[-38.2,17.16],[-38.2,14.5],[-36.56,14.5],[-33.9,17.16],
        [-33.9,22.84],[-36.56,25.5],[-38.2,25.5],[-38.2,22.84],[-40,24.64],
        [-40,30],[-34.64,30],[-32.84,28.2],[-35.5,28.2],[-35.5,26.56],
        [-32.84,23.9],[-27.16,23.9],[-24.5,26.56],[-24.5,28.2],[-27.16,28.2],
        [-25.36,30],[-20,30],[-20,24.64],[-21.8,22.84],[-21.8,25.5],
        [-23.44,25.5],[-26.1,22.84],[-26.1,17.16],[-23.44,14.5],[-21.8,14.5],
        [-21.8,17.16],[-20,15.36],[-20,10],[-14.64,10],[-12.84,8.2],
        [-15.5,8.2],[-15.5,6.56],[-12.84,3.9],[-7.16,3.9],[-4.5,6.56],
        [-4.5,8.2],[-7.16,8.2],[-5.36,10],[5.36,10],[7.16,8.2],
        [4.5,8.2],[4.5,6.56],[7.16,3.9],[12.84,3.9],[15.5,6.56],
        [15.5,8.2],[12.84,8.2],[14.64,10],[20,10],[20,15.36],
        [21.8,17.16],[21.8,14.5],[23.44,14.5],[26.1,17.16],[26.1,22.84],
        [23.44,25.5],[21.8,25.5],[21.8,22.84],[20,24.64]]);
        for (x = [-30,-10,10,30])
        {
            translate([x,0,-1])
            cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
        }

            translate([0,0,-1])
            linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
            [[-2.7,8.2],[2.7,8.2],[2.7,6.24],[6.1,2.84],[6.1,-2.84],
            [2.7,-6.24],[2.7,-8.2],[-2.7,-8.2],[-2.7,-6.24],[-6.1,-2.84],
            [-6.1,2.84],[-2.7,6.24]]);
        for (x = [0,1])
        {
            mirror([x,0,0])
            {
                translate([-30,20,-1])
                cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
                translate([-20,0,-1])
                linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
                [[-6.1,2.84],[-0.74,8.2],[2.7,8.2],[2.7,6.24],[6.1,2.84],
                [6.1,-2.84],[2.7,-6.24],[2.7,-8.2],[-2.7,-8.2],[-2.7,-6.24],
                [-6.1,-2.84]]);
                translate([-30,10,-1])
                linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
                [[-6.24,-2.7],[-8.2,-2.7],[-8.2,2.7],[-6.24,2.7],[-2.84,6.1],
                [2.84,6.1],[6.24,2.7],[8.2,2.7],[8.2,-0.74],[2.84,-6.1],
                [-2.84,-6.1]]);
            }
        }
    }
}
module V_4040(V_Ht = 20)
{
    difference()
    {
        linear_extrude(height = V_Ht, center = false, convexity = 10)polygon(points = 
        [[20,20],[14.64,20],[12.84,18.2],[15.5,18.2],[15.5,16.56],
        [12.84,13.9],[7.16,13.9],[4.5,16.56],[4.5,18.2],[7.16,18.2],
        [5.36,20],[-5.36,20],[-7.16,18.2],[-4.5,18.2],[-4.5,16.56],
        [-7.16,13.9],[-12.84,13.9],[-15.5,16.56],[-15.5,18.2],[-12.84,18.2],
        [-14.64,20],[-20,20],[-20,14.64],[-18.2,12.84],[-18.2,15.5],
        [-16.56,15.5],[-13.9,12.84],[-13.9,7.16],[-16.56,4.5],[-18.2,4.5],
        [-18.2,7.16],[-20,5.36],[-20,-5.36],[-18.2,-7.16],[-18.2,-4.5],
        [-16.56,-4.5],[-13.9,-7.16],[-13.9,-12.84],[-16.56,-15.5],[-18.2,-15.5],
        [-18.2,-12.84],[-20,-14.64],[-20,-20],[-14.64,-20],[-12.84,-18.2],
        [-15.5,-18.2],[-15.5,-16.56],[-12.84,-13.9],[-7.16,-13.9],[-4.5,-16.56],
        [-4.5,-18.2],[-7.16,-18.2],[-5.36,-20],[5.36,-20],[7.16,-18.2],
        [4.5,-18.2],[4.5,-16.56],[7.16,-13.9],[12.84,-13.9],[15.5,-16.56],
        [15.5,-18.2],[12.84,-18.2],[14.64,-20],[20,-20],[20,-14.64],
        [18.2,-12.84],[18.2,-15.5],[16.56,-15.5],[13.9,-12.84],[13.9,-7.16],
        [16.56,-4.5],[18.2,-4.5],[18.2,-7.16],[20,-5.36],[20,5.36],
        [18.2,7.16],[18.2,4.5],[16.56,4.5],[13.9,7.16],[13.9,12.84],
        [16.56,15.5],[18.2,15.5],[18.2,12.84],[20,14.64],[20,20]]);
        translate([0,0,-1])
        linear_extrude(height = V_Ht+2, center = false, convexity = 10)polygon(points = 
        [[12.84,-6.1],[10.2,-6.1],[9.14,-6.24],[8.15,-6.65],[7.3,-7.3],
        [6.65,-8.15],[6.24,-9.14],[6.1,-10.2],[6.1,-12.84],[2.7,-16.24],
        [2.7,-18.2],[-2.7,-18.2],[-2.7,-16.24],[-6.1,-12.84],[-6.1,-10.2],
        [-6.24,-9.14],[-6.65,-8.15],[-7.3,-7.3],[-8.15,-6.65],[-9.14,-6.24],
        [-10.2,-6.1],[-12.84,-6.1],[-16.24,-2.7],[-18.2,-2.7],[-18.2,2.7],
        [-16.24,2.7],[-12.84,6.1],[-10.2,6.1],[-9.14,6.24],[-8.15,6.65],
        [-7.3,7.3],[-6.65,8.15],[-6.24,9.14],[-6.1,10.2],[-6.1,12.84],
        [-2.7,16.24],[-2.7,18.2],[2.7,18.2],[2.7,16.24],[6.1,12.84],
        [6.1,10.2],[6.24,9.14],[6.65,8.15],[7.3,7.3],[8.15,6.65],
        [9.14,6.24],[10.2,6.1],[12.84,6.1],[16.24,2.7],[18.2,2.7],
        [18.2,-2.7],[16.24,-2.7]]);
        for (x = [-10,10])
        {
            for (y = [-10,10])
            {
                translate([x,y,-1])
                cylinder(d=4.2,h=V_Ht+2,center=false,$fn=16);
            }
        }
    }
}
module HullBot(HL = L1,HW = W1)
{
    L2 = HL / 2.0;
    W2 = HW / 2.0;
    X1 = L2- Rnd_Rad;
    Y1 = W2 - Rnd_Rad;
    hull()
    {
        hull()
        {
            translate([-X1,-Y1,0])
            cylinder(d1=Rnd_OD-Rnd_Ht,d2=Rnd_OD,h=Rnd_Ht,$fn=Rnd_Res);
            translate([X1,-Y1,0])
            cylinder(d1=Rnd_OD-Rnd_Ht,d2=Rnd_OD,h=Rnd_Ht,$fn=Rnd_Res);
        }
        hull()
        {
            translate([-X1,Y1,0])
            cylinder(d1=Rnd_OD-Rnd_Ht,d2=Rnd_OD,h=Rnd_Ht,$fn=Rnd_Res);
            translate([X1,Y1,0])
            cylinder(d1=Rnd_OD-Rnd_Ht,d2=Rnd_OD,h=Rnd_Ht,$fn=Rnd_Res);
        }
    }
}
module CutIn()
{
    translate([0,3.9,0])
    rotate([0,0,-90])  
    union()
    {
        translate([-6.2,0,0])
        difference()
        {
            Intrude(0);
            translate([-10,-10,-1])
            cube([11.8+2.5,20,Clip_Ht+2]);
            for (m = [0,1])
            {
                mirror([0,m,0])

                translate([0,2.5,-1])
                cube([10,10,Clip_Ht+2]);
            }
        }
        hull()
        {
            translate([-1.9,0,0])
            rotate([90,0,0])
            cylinder(d=2,h=5,center=true,$fn=4);
            translate([-1.9,0,Clip_Ht-.5])
            rotate([90,0,0])
            cylinder(d=1,h=5,center=true,$fn=4);
        }
        translate([-2.85,2.5,0])
        rotate([90,0,0])
        hull()
        {
            translate([0,0,-1])
            cylinder(d1=0,d2=2,h=1,$fn=4);
            cylinder(d=2,h=5,center=false,$fn=4);
            translate([0,0,5])
            cylinder(d1=2,d2=0,h=1,$fn=4);
            translate([1.14,0,0])
            {
            translate([0,0,-1])
            cylinder(d1=0,d2=2,h=1,$fn=4);
            cylinder(d=2,h=5,center=false,$fn=4);
            translate([0,0,5])
            cylinder(d1=2,d2=0,h=1,$fn=4);
            }
        }
    }
}
module Outtrude()
{
    CutIn();
}
module ClipCut1(C_Ht = Clip_Connect_Ht)
{
    translate([0,0,4])
    linear_extrude(height = C_Ht, center = false, convexity = 10)polygon(points = 
    [[2.7,6.24],[-2.7,6.24],[-6.1,2.84],[-6.1,-2.84],[-2.7,-6.24],
    [2.7,-6.24],[6.1,-2.84],[6.1,2.84]]);
}
module ClipCut2(C_Ht = Clip_Base_Ht)
{
    translate([0,0,0])
    linear_extrude(height = C_Ht, center = false, convexity = 10)polygon(points = 
    [[2.44,5.62],[-2.44,5.62],[-5.48,2.58],[-5.48,-2.58],[-2.44,-5.62],
    [2.44,-5.62],[5.48,-2.58],[5.48,2.58]]);
}
module ClipCut3(C_Ht = .1)
{
    translate([0,0,Clip_Ht-.1])
    linear_extrude(height = .1, center = false, convexity = 10)polygon(points = 
    [[2.18,4.99],[-2.18,4.99],[-4.85,2.32],[-4.85,-2.32],[-2.18,-4.99],
    [2.18,-4.99],[4.85,-2.32],[4.85,2.32]]);
}
module ClipCut4(C_Ht = 11)
{
    translate([0,0,-1])
    linear_extrude(height = Clip_Ht+2, center = false, convexity = 10)polygon(points = 
    [[1.66,3.74],[-1.66,3.74],[-3.6,1.8],[-3.6,-1.8],[-1.66,-3.74],
    [1.66,-3.74],[3.6,-1.8],[3.6,1.8]]);
}
module ClipCut5(C_Ht = 3.75)
{
    translate([0,0,4])
    linear_extrude(height = C_Ht, center = false, convexity = 10)polygon(points = 
    [[1.92,4.37],[-1.92,4.37],[-4.23,2.06],[-4.23,-2.06],[-1.92,-4.37],
    [1.92,-4.37],[4.23,-2.06],[4.23,2.06]]);
}
module Do_Int_CBeam()
{
    for (x = [0:L_Type-1])
    {
        x1 = Int1[x];
        translate([x1,0,Base_Ht-.01])
        Intrude();
    }
    for (m = [0,1])
    {
        mirror([m,0,0])
        translate([-30,10,Base_Ht-.01])
        Intrude();
    }
}
module Intrude(InCut = 1)
{
    difference()
    {
        union()
        {
            
            ClipCut2(Clip_Base_Ht);
            hull()
            {
                translate([0,0,Clip_Base_Ht])
                ClipCut2(.1);
                ClipCut1(Clip_Connect_Ht);
                ClipCut3();
            }
        }
        ClipCut4();
        hull()
        {
            translate([0,0,3.375])
            ClipCut4(.01);
            ClipCut5(5.2);
        }
        if (InCut == 1)
        {
            for (a = [0,90])
            {
                translate([0,0,0])
                rotate([0,0,a])
                translate([-.825,-9.2,-1])
                cube([1.65,18.4,Clip_Ht+2]);         //Cut 2 slots to allow better fit
            }
        }
    }
}
module M5_Holes(M5_X = 0, M5_Y = 0)
{
    translate([M5_X,M5_Y,-1])
    cylinder(d=M5_OD,h=Base_Ht+2,center=false,$fn=M5_OD_Res);
    if (M5_Hd_Ht != 0)
    {
        translate([M5_X,M5_Y,-1])
        cylinder(d=M5_Hd_OD,h=M5_Hd_Ht+1,center=false,$fn=M5_OD_Res);
        translate([M5_X,M5_Y,M5_Hd_Ht-.01])
        cylinder(d1=M5_Hd_OD,d2=M5_OD,h=1.01,center=false,$fn=M5_OD_Res);
    }
}
module Do_Int4040()
{
    for (a = [0,90,180,270])
    {
        rotate([0,0,a])
        translate([0,-22.2,Base_Ht-.01])
        difference()
        {
            CutIn(0);
            translate([-10-2.5,0,-1])
            cube([10.1,10,40]);
            translate([2.45,0,-1])
            cube([10,10,40]);
        }
    }
}
module Do_4040()
{
    for (y = [0,1])
    {
        mirror([0,y,0])
        for (x = [0:1])
        {
            x1 = Ext1[x];
            translate([x1,20,0])
            mirror([0,1,0])
            translate([0,0,Base_Ht-.01])
            Outtrude();
        }
    }
    if (ExtEnd_ON > 0)
    {
        for (m = [0,ExtEnd_ON-1])
        {
            mirror([m,0,0])
            rotate([0,0,90])
            for (x = [0:1])
            {
                x1 = Ext1[x];
                translate([x1,20,0])
                mirror([0,1,0])
                translate([0,0,Base_Ht-.01])
                Outtrude();
            }
        }     
    }
}
module Do_CBeam()
{
    for (x = [0:3])
    {
        x1 = Ext1[x];
        translate([x1,0,0])
        mirror([0,1,0])
        translate([0,0,Base_Ht-.01])
        Outtrude();
    }
    for (x = [1:2])
    {
        x1 = Ext1[x];
        translate([x1,0,0])
        translate([0,0,Base_Ht-.01])
        Outtrude();
    }
    for (m = [0,1])
    {
        mirror([m,0,0])
        translate([-30,10])
        {
            rotate([0,0,90])
            for (x = [1:2])
            {
                x1 = Ext1[x];
                translate([x1,0,0])
                translate([0,0,Base_Ht-.01])
                Outtrude();
            }
            translate([0,10,0])
            rotate([0,0,90])
            mirror([0,1,0])
            translate([0,0,Base_Ht-.01])
            Outtrude();
        }
    }
    if (ExtEnd_ON > 0)
    {
        for (m = [0,1])
        {
            mirror([m,0,0])
                translate([-30,20,0])
                rotate([0,0,180])
                mirror([0,1,0])
                translate([0,0,Base_Ht-.01])
                Outtrude();
        }
    }
}
module DrawFinal()
{
    difference()
    {
        union()
        {
            if (L_Type < 4)
            {
                hull()
                {
                    HullBot();
                    translate([-L1/2,-10,Rnd_Ht])
                    cube([L1,20,B_Ht]);
                }
            } else if (L_Type == 4)
            {
                union()
                {
                    hull()
                    {
                        HullBot(80,20);
                        translate([-40,-10,Rnd_Ht])
                        cube([80,20,Base_Ht]);
                    }
                    for (x = [0,1])
                    {
                        mirror([x,0,0])
                        translate([-30,10,0])
                        rotate([0,0,90])
                        hull()
                        {
                            HullBot(40,20);
                            translate([-20,-10,Rnd_Ht])
                            cube([40,20,Base_Ht]);
                        }
                    }
                }
            } else if (L_Type == 5)
            {
                union()
                {
                    hull()
                    {
                        HullBot(40,40);
                        translate([-20,-20,Rnd_Ht])
                        cube([40,40,B_Ht]);
                    }
                }
            }
            if (Fit_Type == 2 || Fit_Type == 3)
            {
                if (L_Type == 4)
                {
                    Do_CBeam();
                } else if (L_Type == 5)
                {
                    Do_4040();
                    
                }else
                {
                    for (x = [0:L_Type])
                    {
                        x1 = Ext1[x];
                        translate([x1,0,0])
                        for (y = [0,1])
                        {
                            mirror([0,y,0])
                            translate([0,0,Base_Ht-.01])
                            Outtrude();
                        }
                    }
                    if (ExtEnd_ON > 0)
                    {
                        for (x = [0:ExtEnd_ON-1])
                        {
                            x1 = Ext1[x];
                            rotate([0,0,-90])
                            for (y = [0,ExtEnd_ON-1])
                            {
                                mirror([0,y,0])
                                translate([0,E1,Base_Ht-.01])
                                Outtrude();
                            }
                        }
                    }
                }
            }
            if (Fit_Type == 1 || Fit_Type == 3)
            {
                if (L_Type == 0)
                {
                    echo("*****************************************");
                    echo("***ERROR - DOES NOT WORK WITH 2020 V-Slot");
                    echo("*****************************************");
                } else
                {
                    if (L_Type == 4)
                    {
                        Do_Int_CBeam();
                    } else if (L_Type == 5)
                    {
                        Do_Int4040();
                    } else
                    {
                        for (x = [0:L_Type-1])
                        {
                            x1 = Int1[x];
                            translate([x1,0,Base_Ht-.01])
                            Intrude();
                        }
                    }
                }
            }
        }
        if (M5_Hole_ON > 0)
        {
            if (M5_Hole_ON == 1)
            {
                A1_Len = len(HolX1);
                echo(A1_Len = A1_Len);
                for (i = [0:A1_Len-1])
                {
                    X1 = HolX1[i];
                    Y1 = HolY1[i];
                    M5_Holes(X1,Y1);
                }
            } else
            {
                A_Len = len(HolX);
                echo(A_Len = A_Len);
                for (i = [0:A_Len-1])
                {
                    X1 = HolX[i];
                    Y1 = HolY[i];
                    M5_Holes(X1,Y1);
                }
            }
        }
    }
}
//                        HullBot(80,20);
//                        translate([-40,-10,Rnd_Ht])
//                        cube([80,20,Base_Ht]);
if (V_ON == 1)
{
    if (Fit_Type == 0)
    {
        translate([0,0,0])
        color("silver",.5)
        rotate([180,0,0])
        %V_Slot(Clip_Ht);            //Draw ghost of V-slot upside down to match Endcap only type
    } else
    {
        translate([0,0,Base_Ht])
        color("silver",.5)
        %V_Slot(Clip_Ht);            //Draw ghost of V-slot
    }
}
if (Fit_Type == 0)
{
//    difference()
//    {
    translate([0,0,Base_Ht+Rnd_Ht])
    rotate([180,0,0])
    DrawFinal();
//        translate([0,-50,-10])
//        cube([100,100,50]);
//    }
} else
{
    DrawFinal();
}
