//Cover for OpenCase to keep debris out
//11/20/2018    By: David Bunch
//
//Variable layer height I use in prusa Slic3r
//0	- 23.75         .3
//23.75 - 43.55 	.2
//7:48 print time 5.02oz at 3 perimeters & 20% rectangular infill
use <SphinxText_Rev3.scad>
Ires = 2;               //2 = about 2mm arc segments, set to 8 for rough while Editing
V_Hole_ID = 1;          //0 = Original Bottom at 78.4mm offset (156.8mm spacing)
                        //1 = 57.3mm Offset at bottom (114.6mm spacing)
                        //2 = Middle hole Mounts
Part = 0;               //0 = Print Part, 1 = Test print
TrapNut_Columns = 0;    //Add Nut Trap Standoff columns, 0 = No, 1 = Yes
Rot_Part = 0;           //1 = Rotate on Side for printing with no supports needed
Base_Ht = 2.0;          //Height of base below Electronics Mounting points
Collar_Ht = 25;         //How long to make the Wire collar hole into enclosure
//You can make case taller without affecting anything by changing the OP_Ht variable
OP_Ht = 47-6;           //OpenCase Height, 47.0mm is what I measure on sketchup file
Thk = 3.0;              //Outer wall thickness, use either 3 or 4

M5 = 5.5;               //Diameter of M5 screw holes
M5_Res = 20;            //Resolution of M5 holes
M3_OD = 3.8;            //Diameter of M3 screw holes
M3Nut_OD = 6.5356;      //Diameter M3 for Nut Traps
M3Nut_Ht = 4;           //Height of Nut trap
M3NutTapHt = 1.16*2;          //Height of 45 degree taper to meet M3 Hole

//Do not change any of the next 4 variables unless you are going to change a lot of code
OD = 24;                //Used for outer diameter of spheres, I would not change this
Rad = OD / 2;
OD1 = 19.06;            //Diameter of bottom outside cylinder in hulls
//
OD_Z = OP_Ht + Thk - Rad;

OD_Res = (round(((OD * 3.14) / 2) / Ires)*4);      //about 2mm arc segments
OD1_Res = (round(((OD1 * 3.14) / 2) / Ires)*4);

//From Spark concepts mechanical drawing shows 73.3mm between holes along length
// 36.65 * 2 = 73.3mm.
//56.9mm between holes along width 28.45mm * 2 = 56.9mm
//These are the X & Y offset of Board Corner holes from Center of Case
Brd_X1 = 36.65;       //Openbuilds Plate measures 36.9mm     
Brd_Y1 = 28.45;
Brd_Bump_Ht = 9;        //Height of Bumps where controller board connects
Brd_Len  = Brd_X1 * 2;
Brd_Wid = Brd_Y1 * 2;
//
X1 = 86.4-20;          //X offset from center of outside connecting holes for top plate
Y1 = 49;            //Y offset from center of outside connecting holes for top plate
X2 = X1 - Brd_X1;
Y2 = Y1 - Brd_Y1;
L2 = sqrt((X2 * X2) + (Y2 * Y2));   //Angled length of ridge between board & outer holes
Ang_Ridge = atan(Y2/X2);            //Angle of ridge from board mount to outer holes

Rot_Arr = [0,70.1336];     //Rotation angle 3mm thk = -70.1336, 4mm thk = -70.6813
T_Off_Arr = [1.33,2.47];
TZ_Off_Arr = [3,1];
T_IDX = Thk -3;
Rot_Ang = -(Rot_Arr[Rot_Part] + (0.5477*T_IDX));

SXY = T_Off_Arr[T_IDX];
TZ_Off = TZ_Off_Arr[T_IDX];

VX_Arr = [78.4,57.3,57.9];      //X offsets for _ID = 0,1,2
VY_Arr = [-45,-45,10];          //Y offste for _ID = 0,1,2
V_X_Offset = VX_Arr[V_Hole_ID];
V_Y_Offset = VY_Arr[V_Hole_ID];

echo(Ang_Ridge = Ang_Ridge);
echo(L2 = L2);
echo(Rot_Ang = Rot_Ang);
echo(OD_Z = OD_Z);
echo(T_IDX = T_IDX);
echo(SXY = SXY);
echo(OD_Res = OD_Res);
echo(OD1_Res = OD1_Res);
echo("V_X_Offset = ",V_X_Offset);
echo(V_Y_Offset = V_Y_Offset);

Chamf_OD = 3.5;
Chamf_Res = 20;
module OC_Plate()
{
    color("silver",.5)
    %import("OpenCasePlate_Rev10.stl");
    color("blue",.7)
    translate([0,0,-OP_Ht+6])
    for (x = [0,1])
    {
        mirror([x,0,0])
        for (y = [0,1])
        {
            mirror([0,y,0])
            translate([X1,Y1,0])
            %Hex_Standoff(8,4,OP_Ht-6);
        }
    }
}
module Hex_Standoff(H_OD=7,H_ID = 4.0,H_Ht=35)
{
    H_ID_Res = (round(((H_ID * 3.14) / 2) / .7)*4);
    echo(H_ID_Res = H_ID_Res);
    difference()
    {
        cylinder(d=H_OD,h=H_Ht,$fn=6);
        translate([0,0,-1])
        cylinder(d=H_ID,h=H_Ht+2,$fn=H_ID_Res);
    }
}

module Ridge(R_Ht = L2)
{
    difference()
    {
        rotate([0,90,0])
        cylinder(d=14.5,h=R_Ht,center=false,$fn=4);
        translate([-1,-2.5,6])
        cube([R_Ht+2,5,2]);
        translate([-1,-7.5,-8])
        cube([R_Ht+2,15,8]);        
    }
}
module Cutout()
{
    C_OD = 25;
    if (V_Hole_ID < 2)
    {
        translate([0,0,OD_Z])
        hull()
        {
            hull()
            {
                translate([-X1-9.47,-Y1-9.47,0])
                cylinder(d=3,h=100,$fn=44);
                translate([-X1-9.47,Y1+9.47,0])
                cylinder(d=3,h=100,$fn=16);
            }
            hull()
            {
                translate([X1+9.47,-Y1-9.47,0])
                cylinder(d=3,h=100,$fn=44);
                translate([X1+9.47,Y1+9.47,0])
                cylinder(d=3,h=100,$fn=44);
            }
        }
    } else
    {
        translate([0,0,OD_Z])
        hull()
        {
            hull()
            {
                translate([-X1-8.5,-Y1-8.5,0])
                cylinder(d=C_OD-17,h=100,$fn=44);
                translate([-X1-8.5,Y1+8.5,0])
                cylinder(d=C_OD-17,h=100,$fn=44);
            }
            hull()
            {
                translate([X1+8.5,-Y1-8.5,0])
                cylinder(d=C_OD-17,h=100,$fn=44);
                translate([X1+8.5,Y1+8.5,0])
                cylinder(d=C_OD-17,h=100,$fn=44);
            }
        }
    }
}
module SphereHulls(Out_OD = OD,Out_OD1 = OD1,Z1 = 0,SX1 = X1, SY1 = Y1)
{
//    echo(SX1 = SX1);
//    echo(SY1 = SY1);
//    echo(Out_OD1 = Out_OD1);
    hull()
    {
        for (x = [-1,1])
        {
            hull()
            {
                translate([x * X1,Y1,OD_Z])
                translate([x * 10.6,10.6,0])
                sphere(d=Out_OD,$fn=OD_Res);
                translate([x * SX1,SY1,Z1])
                cylinder(d=Out_OD1,h=.1,$fn=OD1_Res);
            }
            hull()
            {
                translate([x * X1,-Y1,OD_Z])
                translate([x * 10.6,-10.6,0])
                sphere(d=Out_OD,$fn=OD_Res);
            
                translate([x *SX1,-SY1,Z1])
                cylinder(d=Out_OD1,h=.1,$fn=OD1_Res);
            }
        }
    }
}
module Base(B_Ht = Base_Ht)
{
    hull()
    {
        hull()
        {
            translate([X1+2.6,-Y1-3,0])
            cylinder(d=6,h=Base_Ht,$fn=24);
            translate([X1+2.6,Y1+3,0])
            cylinder(d=6,h=Base_Ht,$fn=24);
        }
        hull()
        {
            translate([-X1-2.6,-Y1-3,0])
            cylinder(d=6,h=Base_Ht,$fn=24);
            translate([-X1-2.6,Y1+3,0])
            cylinder(d=6,h=Base_Ht,$fn=24);
        }
    }
}
module Brd_Base()
{
    for (y = [0,1])
    {
        mirror([0,y,0])
        for (x = [0,1])
        {
            mirror([x,0,0])
            {
                translate([Brd_X1,-Brd_Y1,0])
                rotate([0,0,-Ang_Ridge])
                Ridge(L2); 

                translate([X1,Y1,0])
                difference()
                {
                    cylinder(d1=20,d2=8,h=6,$fn=40);
                    translate([0,0,-1])
                    cylinder(d=24,h=Base_Ht+1-.1,$fn=40);  //Make sure does not extend beyond outside of part
                }
                if (TrapNut_Columns == 1)
                {
                    translate([X1,Y1,0])
                    cylinder(d=11.25,h=41,$fn=40);
                }
                translate([Brd_X1,Brd_Y1,0])
                cylinder(d1=26,d2=8,h=Brd_Bump_Ht,$fn=20);
            }
        }
    }
    for (y = [-1,1])
    {
        translate([-Brd_X1,y *Brd_Y1,0])
        Ridge(Brd_Len); 
    }
    for (x = [-1,1])
    {
        translate([x*Brd_X1,-Brd_Y1,0])
        rotate([0,0,90])
        Ridge(Brd_Wid); 
    }
//T-slot Mount holes
    for (x = [-1,1])
    {
        translate([x*V_X_Offset,V_Y_Offset,0])
        cylinder(d=12,h=2,$fn=40);
        translate([x*V_X_Offset,V_Y_Offset,2])
        cylinder(d1=18,d2=14,h=4,$fn=40);
    }
    if (V_Hole_ID == 2)
    {
        for (x = [-1,1])
        {
            translate([x*V_X_Offset,-V_Y_Offset,0])
            cylinder(d=12,h=2,$fn=40);
            translate([x*V_X_Offset,-V_Y_Offset,2])
            cylinder(d1=18,d2=14,h=4,$fn=40);
        }
    }
//    if (V_Hole_ID == 1)
//    {
//        translate([-114.6/2,-45,0])
//        Ridge(114.6);
//    }
}
module CutBotVslot()
{
    if (V_Hole_ID == 1)
    {
//        translate([0,0,-1])
//        linear_extrude(height = Base_Ht+6, center = false, convexity = 10)polygon(points = 
//        [[42.6,-48],[-42.6,-48],[-43.53,-48.04],[-44.45,-48.14],[-45.37,-48.32],
//        [-46.26,-48.57],[-47.14,-48.89],[-47.98,-49.28],[-48.8,-49.72],[-49.57,-50.23],
//        [-50.31,-50.8],[-51,-51.43],[-51.69,-52.04],[-52.44,-52.58],[-53.24,-53.03],
//        [-54.08,-53.41],[-54.96,-53.69],[-55.86,-53.88],[-56.77,-53.99],[-57.69,-53.99],
//        [-58.61,-53.9],[-59.51,-53.72],[-60.39,-53.45],[-61.24,-53.09],[-62.14,-52.68],
//        [-63.06,-52.31],[-64,-51.99],[-64.95,-51.72],[-65.92,-51.49],[-66.9,-51.31],
//        [-67.88,-51.18],[-68.87,-51.1],[-69.86,-51.07],[-70.85,-51.09],[-71.84,-51.15],
//        [-72.82,-51.27],[-73.8,-51.43],[-74.77,-51.65],[-75.73,-51.91],[-76.67,-52.21],
//        [-77.6,-52.57],[-78.5,-52.97],[-79.39,-53.41],[-80.25,-53.9],[-81.09,-54.43],
//        [-81.9,-55],[-82.62,-55.46],[-83.38,-55.84],[-84.18,-56.13],[-85.02,-56.33],
//        [85.02,-56.33],[84.18,-56.13],[83.38,-55.84],[82.62,-55.46],[81.9,-55],
//        [81.09,-54.43],[80.25,-53.9],[79.39,-53.41],[78.5,-52.97],[77.6,-52.57],
//        [76.67,-52.21],[75.73,-51.91],[74.77,-51.65],[73.8,-51.43],[72.82,-51.27],
//        [71.84,-51.15],[70.85,-51.09],[69.86,-51.07],[68.87,-51.1],[67.88,-51.18],
//        [66.9,-51.31],[65.92,-51.49],[64.95,-51.72],[64,-51.99],[63.06,-52.31],
//        [62.14,-52.68],[61.24,-53.09],[60.39,-53.45],[59.51,-53.72],[58.61,-53.9],
//        [57.69,-53.99],[56.77,-53.99],[55.86,-53.88],[54.96,-53.69],[54.08,-53.41],
//        [53.24,-53.03],[52.44,-52.58],[51.69,-52.04],[51,-51.43],[50.31,-50.8],
//        [49.57,-50.23],[48.8,-49.72],[47.98,-49.28],[47.14,-48.89],[46.26,-48.57],
//        [45.37,-48.32],[44.45,-48.14],[43.53,-48.04]]);
    } else if (V_Hole_ID == 0)
    {
        translate([0,0,-1])
        linear_extrude(height = Base_Ht+2, center = false, convexity = 10)polygon(points = 
        [[-77.25,-53.93],[-85.02,-54.84],[-85.02,-55.84],[85.02,-55.84],[85.02,-54.84],
        [77.25,-53.93],[76.36,-53.77],[75.5,-53.52],[74.66,-53.19],[73.86,-52.78],
        [73.11,-52.29],[72.41,-51.72],[71.77,-51.09],[71.19,-50.4],[70.58,-49.7],
        [69.87,-49.11],[69.08,-48.63],[68.22,-48.28],[67.32,-48.07],[66.39,-48],
        [-66.39,-48],[-67.32,-48.07],[-68.22,-48.28],[-69.08,-48.63],[-69.87,-49.11],
        [-70.58,-49.7],[-71.19,-50.4],[-71.77,-51.09],[-72.41,-51.72],[-73.11,-52.29],
        [-73.86,-52.78],[-74.66,-53.19],[-75.5,-53.52],[-76.36,-53.77]]);
    }
}
module DrawBrdBase()
{
    difference()
    {
        union()
        {
            Brd_Base();
            Base();
        }
    }
}
module ChamEd(C_Ht = 59.94)
{
    difference()
    {
        cylinder(d=16,h=C_Ht,center=true,$fn=16);
        translate([0,0,0])
        cylinder(d=M3_OD,h=C_Ht+2,center=true,$fn=16);
        translate([-16,0,-C_Ht/2])
        cube([32,16,C_Ht+2]);
    }
}
module ChamfTopCorner()
{
    Ch_Rot = 360.0 / Chamf_Res;
    difference()
    {
        cylinder(d=Chamf_OD*1.71,h=5,center=true,$fn=44);

        rotate_extrude(convexity = 10,$fn=44)
        translate([3, 0, 0])
        rotate([0,0,Ch_Rot])
        circle(d=Chamf_OD, $fn = Chamf_Res);
        rotate_extrude(convexity = 10,$fn=44)
        translate([3, 0, 0])
        rotate([0,0,Ch_Rot])
        circle(d=Chamf_OD, $fn = Chamf_Res);
    }
}
module ChamEdge(C_Ht = 57.5*2)
{
    difference()
    {
        cylinder(d=Chamf_OD*3,h=C_Ht,center=true,$fn=Chamf_Res);
        cylinder(d=Chamf_OD,h=C_Ht+2,center=true,$fn=Chamf_Res);
        translate([-12,-6,-C_Ht/2-1])
        cube([12,12,C_Ht+2]);
    }
}
module DrawUnion()
{
    rotate([Rot_Ang,0,0])
    difference()
    {
        union()
        {
            difference()
            {
                SphereHulls();
                SphereHulls(OD - (Thk * 2),16.75,2,X1 - SXY,Y1 - SXY);
                Cutout();
            }
            DrawBrdBase();
        }
//        if (V_Hole_ID < 2)
//        {
//            translate([-150,-100-54.84,-1])
//            cube([300,100,100]);
//        }
        for (x = [0,1])
        {
            mirror([x,0,0])
            {
                for (y = [0,1])
                {
                    mirror([0,y,0])
                    {
                        if (TrapNut_Columns == 1)
                        {
                            translate([X1,Y1,Base_Ht])
                            cylinder(d=M3_OD,h=70,$fn=20);
                        } else
                        {
                            translate([X1,Y1,-1])
                            cylinder(d=M3_OD,h=20,$fn=20);
                            translate([X1,Y1,-1])
                            cylinder(d=6,h=3,$fn=24);
                            translate([X1,Y1,1.99])
                            cylinder(d1=6,d2=M3_OD,h=1,$fn=24);
                        }
    
                        translate([Brd_X1,Brd_Y1,-1])
                        cylinder(d=M3_OD,h=10+2,$fn=20);
                    }
                }
                translate([V_X_Offset,V_Y_Offset,-1])
                cylinder(d=M5,h=Base_Ht+8,$fn=M5_Res);
        if (V_Hole_ID == 2)
        {
            for (x = [-1,1])
            {
                translate([x * V_X_Offset,-V_Y_Offset,-1])
                %cylinder(d=M5,h=Base_Ht+8,$fn=M5_Res);
            }
        }
            }
        }
//Add M3 Nut Trap
        if (TrapNut_Columns == 1)
        {
            for (y = [0,1])
            {
                mirror([0,y,0])
                for (x = [0,1])
                {
                    mirror([x,0,0])
                    translate([X1,Y1,32-M3Nut_Ht])
                    hull()
                    {
                        translate([0,0,0])
                        rotate([0,0,45])
                        cylinder(d=M3Nut_OD,h=M3Nut_Ht,$fn=6);
                        translate([-5,-5,0])
                        rotate([0,0,45])
                        cylinder(d=M3Nut_OD,h=M3Nut_Ht,$fn=6);
                    }
                    mirror([x,0,0])
                    translate([X1,Y1,32-M3Nut_Ht+M3Nut_Ht-.01])
                    hull()
                    {
                        translate([0,0,0])
                        rotate([0,0,45])
                        cylinder(d1=M3Nut_OD,d2=M3_OD-1,h=M3NutTapHt,$fn=6);
                        translate([-5,-5,0])
                        rotate([0,0,45])
                        cylinder(d1=M3Nut_OD,d2=M3_OD-1,h=M3NutTapHt,$fn=6);
                    }
                }
            }
        }

        for (y = [0,1])
        {
            mirror([0,y,0])
            for (x = [0,1])
            {
                mirror([x,0,0])
                translate([X1+10.97,Y1+10.97,OP_Ht + .92])    //97.37,59.97
                ChamfTopCorner();
            }
        }
        for (xy = [0,1])
        {
            mirror([xy,0,0])
            translate([-X1 - 13.95,0,OP_Ht + .92])
            rotate([90,0,0])
            ChamEdge(Y1 * 2 + 22.2);
            mirror([0,xy,0])
            translate([0,Y1 + 13.95,OP_Ht + .92])
            rotate([0,-90,0])
            rotate([0,0,-90])
            ChamEdge(X1 * 2 + 22.2);
        }
        CutBotVslot();
    }
}
module WireHold()
{
    W_Rad = 9.25;
    difference()
    {
        union()
        {
            translate([0,0,12])
            difference()
            {
                rotate([0,90,0])
                rotate_extrude(convexity = 10, $fn = 86)
                translate([W_Rad, 0, 0])
                circle(d=4, $fn = 20);
                translate([0,0,-50])
                cylinder(d=40,h=50,$fn=12);
            }
            translate([0,0,5])
            difference()
            {
                rotate([0,90,0])
                rotate_extrude(convexity = 10, $fn = 8)
                translate([W_Rad, 0, 0])
                circle(d=4, $fn = 20);
                translate([0,0,0])
                cylinder(d=40,h=50,$fn=12);
        
                translate([0,0,-55])
                cylinder(d=40,h=50,$fn=12);
                }
            translate([0,-W_Rad,5])
            cylinder(d=4,h=12-5,$fn=20);
            translate([0,W_Rad,5])
            cylinder(d=4,h=12-5,$fn=20);
            for (y = [-1,1])
            {
                translate([0,y * 8.4,0])
                cylinder(d1=8,d2=4,h=3,$fn=20);
            }
        }
        translate([-10,10.41,-.02])
        cube([20,10,3]);
    }
}
module InWireHold()
{
//    translate([0,0,2])
    union()
    {
        difference()
        {
            rotate([0,90,0])
            rotate_extrude(convexity = 10, $fn = 44)
            translate([5.5, 0, 0])
            circle(d=3, $fn = 16);
            translate([0,0,-50])
            cylinder(d=40,h=50,$fn=12);
        }
        for (y = [-1,1])
        {
            translate([0,y * 5.3,0])
            cylinder(d1=6,d2=3,h=1.5,$fn=16);
        }
    }
}
module Collar()
{
    difference()
    {
        rotate([0,-90,0])
        union()
        {
            cylinder(d=27,h=Collar_Ht,$fn=96);
            translate([0,0,Collar_Ht])
            rotate_extrude(convexity = 10, $fn = 96)
            translate([12, 0, 0])
            circle(d=3, $fn = 20);
    
            hull()
            {
                translate([-13.04,-7,1])
                cylinder(d=3.9,h=Collar_Ht,$fn=20);
                translate([-13.04,7,1])
                cylinder(d=3.9,h=Collar_Ht,$fn=20);
            }
        }
        rotate([0,23.91,0])
        translate([-7.5,-25,-25])
        cube([50,50,50]);
    }
}
//86.4
//X1
module DrawFinal()
{
    union()
    {
    difference()
    {
        union()
        {
            DrawUnion();
            for (a = [0,180])
            {
                rotate([0,0,a])
                for (y = [22.05,-24.75])
                {
                    translate([X1+23.88,y,15])
                    Collar();
                }
            }
//Add a rib on each end of bottom of case to stiffen case more
//            for (m = [0,1])
//            {
//                mirror([m,0,0])
//                difference()
//                {
//                    hull()
//                    {
//                        translate([Brd_X1+12,0,0])
//                        sphere(d=6,$fn=24);
//                        translate([X1+20,0,0])
//                        cylinder(d=8,h=Base_Ht,$fn=24);
//                        translate([X1+20,0,22])
//                        sphere(d=6,$fn=24);
//                    }
//                    translate([0,0,-9.5])
//                    cylinder(d=300,h=10,$fn=12);
//                }
//            }
        }
        for (a = [0,180])
        {
            rotate([0,0,a])
            for (y = [22.05,-24.75])
            {
                translate([X1+23.88,y,15])
                rotate([0,-90,0])
                {
                    translate([0,0,-1])
                    cylinder(d=21,h=Collar_Ht+2,$fn=96);
                }
                translate([102.58,y,15-.6])
                rotate([0,-90+23.9109,0])
                scale([1.09380952,1,1])     //Scale because cut is on 23.9109 angle
                translate([0,0,-.01])
                cylinder(d1=24,d2=21,h=1.51,$fn=96);
            }
        }

//        translate([-150,-100,-1])
//        cube([300,122.05,200]);
//        translate([-150,-100,-1])
//        cube([150,300,200]);

//    translate([0,-100,-10])
//    cube([200,200,100]);              //Section cut
//    translate([-150,-100,-10])
//    cube([300,100,100]);              //Section cut
        if (Part == 1)
        {
            translate([-75,-100,-10])
            cube([300,200,80]);
            translate([-200,-100,-10])
            cube([200,135,100]);
        }
    }
//Wire Tie holds at top & bottom of xPRO board
        for (x = [-36.4,-3,36.4])
        {
            for (y = [0,1])
            {
                mirror([0,y,0])
                difference()
                {
                    translate([x,49,1.99])
                    WireHold();
                }
            }
        }
        for (x = [-1,1])
        {
            for (y = [-35.22,-8.75,8.75,35.22])
            {
                translate([x * 66.78,y,1.99])
                InWireHold();
            }
        }
    }
}
//%cylinder(d=4,h=100,center=true,$fn=4);
//translate([0,0,32])
//rotate([0,0,45])
//%cylinder(d=113.14,h=11,$fn=4);
//translate([0,0,43.56-3])
//rotate([-90,0,0])
//translate([0,60.98,-40.04])
//color("blue",.5)
//import("Fan_80x80x11_24v.stl");
//rotate([0,0,180])     //In case you want to rotate electronics the other way
translate([0,0,Brd_Bump_Ht])
color("red",.5)
%import("xPRO_Board_V3.stl");

//translate([0,0,OP_Ht])
//OC_Plate();
//translate([0,0,40])
//rotate([-90,0,0])
//translate([0,60.98,-40.04])
//color("blue",.5)
//%import("Fan_80x80x11_24v.stl");
//WireHold();
difference()
{
    DrawFinal();

//    translate([0,-100,-10])
//    cube([200,200,100]);
//    translate([-129,-100,-10])
//    cube([100,200,100]);
//    translate([-100,-36,-10])
//    cube([200,200,100]);
//    translate([0,0,26])
//    cylinder(d=500,h=100,$fn=24);
    translate([0,9,-1])
    scale([1.2,1.2,1])
    SphinxLogo(2);
    translate([0,45,1])
    rotate([0,0,180])
    rotate([180,0,0])
    difference()
    {
        SphinxOutline();
        Let_S();
        Let_P();
        Let_H();
        Let_I();
        Let_N();
        Let_X();
    }
}