//V-Slot Brackets for Meanwell 24v PS With or Without PowerCase
//12/19/2018    By: David Bunch
//
Print_Type = 1;     //0 = display for Print, 1 = Display Assembled
TestPrint_ON = 0;   //1 = Test Print
PowerCase_ON = 1;   //0 = Just 24v PowerSupply, 1 = Use PowerCase Design
//V-Slot Size for Reference only
L1 = 80;            //[20:2020, 40:2040, 60:2060, 80:2080, 100:C-Beam, 120:4040]
Sphinx = 1;         //Draw Cbeam with (Sphinx Y plate with M5 Heads attached) for reference
PS_ON = 1;          //Display Power Supply or PowerCase in Assembly View
Base_Ht = 7;        //Base Height of what PS sits on

PS_X = 32;          //How far to offset PS from V-Slot connection
                    //45 - 7 = 38mm from edge of mount bracket
                    //Use a minimum of 7 since V-Slot Wall part is 7mm thick
PSF_Y = 0;         //Y offset for Front Bracket
PSB_Y = 0;         //Y offset for Back Bracket
LenFront = 73;      //Length of Front of PS Channel, Use a minimum of 73
LenBack = 40;       //Length of Back of PS Channel, Use a minimum of 40

M3_OD = 3.8;        //Diameter for M3 screws
M4_OD = 4.5;        //Diameter for M5 screws
M5_OD = 5.6;        //Diameter for M4 screws
M3Hd_OD = 6.5;      //Diameter for M3 screw Head
M4Hd_OD = 8;        //Diameter for M4 screw Head
M5Hd_OD = 11;       //Diameter for M5 screw Head

M3_OD_Res = 20;     //M3 Screw Resolution (# of Arc segments)
M4_OD_Res = 24;     //M4 Screw Resolution 
M5_OD_Res = 24;     //M5 Screw Resolution 
M3Hd_OD_Res = 24;   //M3 Screw Head Resolution 
M4Hd_OD_Res = 32;   //M4 Screw Head Resolution 
M5Hd_OD_Res = 48;   //M5 Screw Head Resolution 

PS_Wid = 30.3;      //Width of PS with Tolerance Added (.3mm tolerance)
PS_Wall_Ht = 27;    //Height of Wall around PS

PS_Wall_Thk = 5;    //Thickness of PS Wall
PS_B_Ht = Base_Ht;  //Base Height of where PS sits on
PS_Wall_Wid = PS_Wid + PS_Wall_Thk + PS_Wall_Thk;
PS_Wall_Wid2 = PS_Wall_Wid / 2;
PS_Wall_Thkx2 = PS_Wall_Thk * 2;

CP_OD = 4;          //Chamfer Edge Round Diameter, I would not change this

X3 = PS_X + PS_Wall_Wid;
M4_Offset = PS_X + PS_Wall_Wid2 - 2.65;     //PS M4 hole is 2.65mm offset from center
L_Type = ((L1 / 10) / 2) - 1;       //20 = 0, 40 = 1, 60 = 2, 80 = 3
CX_Arr = [0,10,20,30,30,10];
CY_Arr = [-50,-50,-50,-50,-50,-60];
VX_Arr = [-10,-20,-30,-40,-40,-20];     //X offsets to Display V-Slots in proper spot
VY_Arr = [-10,-10,-10,-10,-30,-20];       //Y offsets to Display V-Slots in proper spot
VY_Offset = VY_Arr[L_Type];
VX_Offset = VX_Arr[L_Type];
CX_Offset = CX_Arr[L_Type];
CY_Offset = CY_Arr[L_Type];
VSlot_Len = PSF_Y + 217 + (PowerCase_ON * 32) + PSB_Y;
echo(PS_Wall_Wid = PS_Wall_Wid);
echo(X3 = X3);

echo(M4_Offset = M4_Offset);
echo(PS_X = PS_X);
echo(PSF_Y = PSF_Y);
echo(PSB_Y = PSB_Y);
echo(VSlot_Len = VSlot_Len);
echo(L_Type = L_Type);
module V_Slot(VS_Ht = 50)
{
    echo(VX_Offset = VX_Offset);
    if (L_Type == 0)V_2020(VS_Ht);
    if (L_Type == 1)V_2040(VS_Ht);
    if (L_Type == 2)V_2060(VS_Ht);
    if (L_Type == 3)V_2080(VS_Ht);
    if (L_Type == 4)CB_4080(VS_Ht);
    if (L_Type == 5)V_4040(VS_Ht);
    if (Sphinx == 1)
    {
        translate([CX_Offset,CY_Offset,0])
        rotate([0,0,-90])
        CB_4080(VS_Ht);
    }
}
module V_2020(V_Ht = 10)
{
    scale([1,1,V_Ht])
    import("V2020_1mm.stl");
}
module V_2040(V_Ht = 10)
{
    scale([1,1,V_Ht])
    import("V2040_1mm.stl");
}
module V_2060(V_Ht = 10)
{
    scale([1,1,V_Ht])
    import("V2060_1mm.stl");
}
module V_2080(V_Ht = 10)
{
    scale([1,1,V_Ht])
    import("V2080_1mm.stl");
}
module CB_4080(V_Ht = 10)
{
    scale([1,1,V_Ht])
    import("C_Beam_1mm.stl");
}
module V_4040(V_Ht = 20)
{
    scale([1,1,V_Ht])
    import("V4040_1mm.stl");
}
module Sphinx_Y_Plate()
{
    import("Sphinx_Y_Plate_WithM5Heads_Rev1.stl");
}
module PS_Case()
{
    color("silver",.8)
    translate([PS_X + PS_Wall_Wid2 - 15,PSF_Y,PS_B_Ht])
    difference()
    {
        cube([30,215 + 34,115]);
        translate([12.5,32.5 + 33,-1])
        cylinder(d=4,h=117,$fn=16);
        translate([12.5,182.5 + 32,-1])
        cylinder(d=4,h=117,$fn=16);
    }
}
module PS()
{
    color("silver",.8)
    translate([PS_X + PS_Wall_Wid2 - 15,PSF_Y+2,PS_B_Ht])
    difference()
    {
        cube([30,215,115]);
        translate([12.5,32.5,-1])
        cylinder(d=4,h=117,$fn=16);
        translate([12.5,215-32.5,-1])
        cylinder(d=4,h=117,$fn=16);
    }
}
module PS_Slot(PS_Wall_Len = LenFront)
{
    difference()
    {
        cube([PS_Wall_Wid,PS_Wall_Len,PS_Wall_Ht]);
        translate([PS_Wall_Thk,-1,PS_B_Ht])
        cube([PS_Wid,PS_Wall_Len + 2,PS_Wall_Ht]);
    }
}
module ChamChannel(CH_OD = 24,CH_Ht = 50,CH_Res = 24)
{
    CH_ODx2 = CH_OD * 2;
    rotate([0,90,0])
    translate([0,0,-1])
    difference()
    {
        cylinder(d=CH_ODx2,h=CH_Ht,$fn=CH_Res);
        translate([0,0,-1])
        cylinder(d=CH_OD,h=CH_Ht + 2,$fn=CH_Res);
        translate([-CH_OD,0,-1])
        cube([CH_ODx2,CH_ODx2,CH_Ht + 2]);
        translate([0,-CH_OD,-1])
        cube([CH_OD,CH_ODx2,CH_Ht + 2]);
    }
}
module RndPS_Edge()
{
    rotate_extrude(angle=90, convexity=10,$fn=96)
    translate([12, 0])
    circle(d=CP_OD,$fn=4);
}
module OCT1(OC_Ht = .01)
{
    rotate([0,90,0])
    rotate([0,0,22.5])
    cylinder(d=20,h=OC_Ht,$fn=8);
}
module OCT2(OC_Ht = .01)
{
    difference()
    {
        rotate([0,90,0])
        rotate([0,0,22.5])
        cylinder(d=20,h=OC_Ht,$fn=8);
        translate([-1,3.8268,-10])
        cube([OC_Ht + 2,20,20]);
    }
}
module Oct3(OC_Ht = .01)
{
    rotate([0,-90,0])
    rotate([0,0,-90])
    linear_extrude(height = OC_Ht, center = false, convexity = 10)polygon(points = 
    [[0,0],[23.24,0],[23.24,10.26],[17.83,17.51],[7.34,17.47],
    [2,10.7],[0,7.7]]);
}
module Oct4(OC_Ht = .01)
{
    rotate([0,-90,0])
    rotate([0,0,-90])
    linear_extrude(height = OC_Ht, center = false, convexity = 10)polygon(points = 
    [[24.49,0],[0,0],[0,14.81],[5.44,17.5],[17.99,17.5],
    [24.49,10]]);
}
module Oct5(OC_Ht = .01)
{
    rotate([0,-90,0])
    rotate([0,0,-90])
    linear_extrude(height = OC_Ht, center = false, convexity = 10)polygon(points = 
    [[0,0],[20.48,0],[20.48,10.3],[15.07,17.6],[7.41,17.6],
    [2,10.7],[0,7.7]]);
}
module Oct6(OC_Ht = .01)
{
    rotate([0,-90,0])
    rotate([0,0,-90])
    linear_extrude(height = OC_Ht, center = false, convexity = 10)polygon(points = 
    [[31.77,0],[31.76,10.3],[37.17,17.6],[44.83,17.6],[50.24,10.3],
    [50.25,0]]);
}
module Oct7(OC_Ht = .01)
{
    rotate([0,-90,0])
    rotate([0,0,-90])
    linear_extrude(height = OC_Ht, center = false, convexity = 10)polygon(points = 
    [[0,0],[50.25,0],[50.24,10.3],[20.48,10.3],[0,7.7]]);
}
module ChamVS_Connect()
{
    translate([7,0,19.5])
    rotate([-90,0,0])
    cylinder(d=CP_OD,h=50,$fn=4);
    translate([7,12,19.5 - 12])
    rotate([0,-90,0])
    rotate([0,0,-90])
    rotate_extrude(angle=90, convexity=10,$fn=96)
    translate([13.02, 0])
    circle(d=6,$fn=4);
}
module ChamPS_Edge(Len = LenFront, Y_Offset = PSF_Y)
{
    for (y = [Y_Offset,Len + Y_Offset])
    {
        translate([PS_X,y,10.7])
        {
            translate([0,0,-3])
            cylinder(d1=0,d2=CP_OD,h=3,$fn=4);
            cylinder(d=CP_OD,h=PS_Wall_Ht + 2,$fn=4);
        }
    }
    translate([X3,Y_Offset,-1])
    cylinder(d=CP_OD,h=PS_Wall_Ht + 2,$fn=4);
    translate([X3,Len + Y_Offset,-1])
    cylinder(d=CP_OD,h=PS_Wall_Ht + 2,$fn=4);

    translate([PS_X,Y_Offset,PS_Wall_Ht])
    rotate([-90,0,0])
    cylinder(d=CP_OD,h=Len,$fn=4);
    translate([X3,Y_Offset,PS_Wall_Ht])
    rotate([-90,0,0])
    cylinder(d=CP_OD,h=Len,$fn=4);

    translate([PS_X,Y_Offset + 12,PS_Wall_Ht - 12])
    rotate([0,-90,0])
    rotate([0,0,-90])
    RndPS_Edge();
    translate([X3,Y_Offset + 12,PS_Wall_Ht - 12])
    rotate([0,-90,0])
    rotate([0,0,-90])
    RndPS_Edge();

    translate([X3,Len + Y_Offset - 12,PS_Wall_Ht - 12])
    rotate([0,-90,0])
    rotate([0,0,0])
    RndPS_Edge();
    translate([PS_X,Len + Y_Offset - 12,PS_Wall_Ht - 12])
    rotate([0,-90,0])
    rotate([0,0,0])
    RndPS_Edge();
}
module HullBridgeF(Len = LenFront)
{
    HY_Scale = .75;
    if (PS_X > 9)
    {
        hull()
        {
            translate([7,41.48,0])
            Oct4();
            translate([32,73,0])
            Oct5();
        }
        hull()
        {
            translate([7,41.48,0])
            Oct4();
            translate([32,73,0])
            Oct6();
        }
        hull()
        {
            translate([7,41.48,0])
            Oct4();
            translate([32,73,0])
            Oct7();
        }
        translate([18,36,0])
        cube([14,12,10.3]);
//        scale([1,1,1.35])
//        hull()
//        {
//            translate([7,26,Base_Ht - 3.2])
//            scale([1,HY_Scale,1])
//            OCT1();
//    
//            translate([PS_X - .01,32,Base_Ht - 3.2])
//            scale([1,1,1])
//            OCT1();
//        }
//        scale([1,1,1.35])
//        hull()
//        {
//            translate([7,32 + 9.24-9,Base_Ht - 3.2])
//            scale([1,1,1])
//            OCT1();
//    
//            translate([PS_X - .01,Len + PSF_Y - 9.24-2,Base_Ht - 3.2])
//            scale([1,1,1])
//            OCT1();
//        }
    } else
    {
        hull()
        {
            cube([7,50.48,5.4]);
            translate([PS_X,PSF_Y,0])
            cube([.1,LenFront,5.4]);
        }
    }
}
module DrawFrontMount()
{
    CC_OD = 24;
    CC_Rad = CC_OD / 2;
    difference()
    {
        union()
        {
//V-Slot Wall Connection
            if (TestPrint_ON == 0)
            {
                difference()
                {
                    hull()
                    {
                        cube([7,32,19.5]);
                        translate([0,32 + 9.24,Base_Ht - 3.2])
                        OCT1(7);
                    }
                    ChamVS_Connect();               //Chamfer outside edge of V-Slot connection
                }
//Bridge between V-Slot Wall & PS_Slot
                HullBridgeF();
            }
            difference()
            {
                translate([PS_X,PSF_Y,0])
                PS_Slot(LenFront);                        //U Channel mount for PS
                ChamPS_Edge(LenFront, PSF_Y);
                translate([PS_X,PSF_Y + CC_Rad,PS_Wall_Ht - CC_Rad])
                ChamChannel(CC_OD,PS_Wall_Wid + 2,96);
                translate([PS_X,PSF_Y + LenFront - CC_Rad,PS_Wall_Ht - CC_Rad])
                mirror([0,1,0])
                ChamChannel(CC_OD,PS_Wall_Wid + 2,96);
            }
        }
        translate([7,0,-1])
        cylinder(d=CP_OD,h=20,$fn=4);           //Outside Lower Corner
//Mount holes in Side of PowerCase Addon
        translate([PS_X + PS_Wall_Wid2,PSF_Y + 18.5,Base_Ht + 8])
        rotate([0,90,0])
        cylinder(d=M3_OD,h=42,center=true,$fn=M3_OD_Res);

//We Add 14mm to height of Head in case plastic needs to be cut to access hole
        translate([PS_X - 1-14,PSF_Y + 18.5,Base_Ht + 8])
        rotate([0,90,0])
        cylinder(d=M3Hd_OD,h=PS_Wall_Thk-2+14,$fn=M4Hd_OD_Res);     //Cut to Recess M3 Head
        translate([X3 + 1,PSF_Y + 18.5,Base_Ht + 8])
        rotate([0,-90,0])
        cylinder(d=M3Hd_OD,h=PS_Wall_Thk - 2,$fn=M4Hd_OD_Res);     //Cut to Recess M3 Head

        translate([0,CC_Rad,20 - CC_Rad])
        ChamChannel(CC_OD,8.1,96);
        translate([M4_Offset,PSF_Y + 65.5,-1])
        {
            cylinder(d=M4_OD,h=Base_Ht + 2,$fn=M4_OD_Res);     //M4 Hole to Mount PS
            cylinder(d=M4Hd_OD,h=4,$fn=M4Hd_OD_Res);           //M4 Screw Head to Mount PS

            translate([0,0,3.99])
            cylinder(d1=M4Hd_OD,d2=M4_OD,h=1.5,$fn=M4_OD_Res); //M4 Screw Head to Mount PS
        }
        translate([-1,10,10])
        rotate([0,90,0])
        cylinder(d=M5_OD,h=20,$fn=M5_OD_Res);     //M5 T-Nut Mount Hole
        translate([6.5,10,10])
        rotate([0,90,0])
        cylinder(d1=M5Hd_OD,d2=M5Hd_OD + 1,h=.51,$fn=M5Hd_OD_Res);     //M5 Head T-Nut Mount Hole
//In case user adjust design, Allow for M5x12mm screw access
        translate([7,10,10])
        rotate([0,90,0])
//sphere does not come out same OD as cylinder, so hull it
        hull()
        {
            cylinder(d=M5Hd_OD + 1,h=13,$fn=M5Hd_OD_Res);
            translate([0,0,13])
            sphere(d=M5Hd_OD + 1,$fn=M5Hd_OD_Res);
        }
//Cutout some below PS mount
        translate([PS_X + PS_Wall_Wid2 - 6.15,PSF_Y + 9,-1])
        hull()
        {
            cylinder(d=6,h=10,$fn=24);
            translate([12.3,0,0])
            cylinder(d=6,h=10,$fn=24);
            translate([0,44.75,0])
            cylinder(d=6,h=10,$fn=24);
            translate([12.3,44.75,0])
            cylinder(d=6,h=10,$fn=24);
        }
        translate([-.001,50.48-9,-1])
        cube([7.002,20,20]);
        translate([0,50.48-9,-1])
        cylinder(d=7,h=20,$fn=4);
        
        translate([-1,-1,-10])
        cube([200,200,10]);
    }
}
module HullBridgeB(Len = LenBack)
{
    if (PS_X > 9)
    {            
        hull()
        {
            scale([1,1,1.34])
            translate([7,26,Base_Ht - 3.2+.0289])
            OCT2();
            scale([1,1,1.34])
            translate([7,32 + 9.24 + 5.4-5.4-8-1.2,Base_Ht-3.2])
            mirror([0,1,0])
            OCT2();
            translate([32,40,0])
            Oct3();
        }
    } else
    {
        hull()
        {
            cube([7,50.48,5.4]);
            translate([PS_X,PSB_Y,0])
            cube([.1,LenBack,5.4]);
        }
    }
}
module DrawBackMount()
{
    CC_OD = 24;
    CC_Rad = CC_OD / 2;
    difference()
    {
        union()
        {
//V-Slot Wall Connection
            if (TestPrint_ON == 0)
            {
                difference()
                {

                    hull()
                    {
                        cube([7,32,19.5]);
                        translate([0,32 + 9.24,Base_Ht - 3.2])
                        rotate([0,90,0])
                        rotate([0,0,22.5])
                        cylinder(d=20,h=7,$fn=8);
                    }
                    ChamVS_Connect();               //Chamfer outside edge of V-Slot connection
                }
//Bridge between V-Slot Wall & PS_Slot
                HullBridgeB();
            }
            difference()
            {
                translate([PS_X,PSB_Y,0])
                PS_Slot(LenBack);                        //U Channel mount for PS
                ChamPS_Edge(LenBack, PSB_Y);
                translate([PS_X,PSB_Y + CC_Rad,PS_Wall_Ht - CC_Rad])
                ChamChannel(CC_OD,PS_Wall_Wid + 2,96);
                translate([PS_X,LenBack + PSB_Y - 12,PS_Wall_Ht - CC_Rad])
                mirror([0,1,0])
                ChamChannel(CC_OD,PS_Wall_Wid + 2,96);
            }
        }
        translate([7,0,-1])
        cylinder(d=CP_OD,h=20,$fn=4);           //Outside Lower Corner

        translate([0,CC_Rad,20 - CC_Rad])
        ChamChannel(CC_OD,8.1,96);
        translate([M4_Offset,34.5 + PSB_Y,-1])
        {
            cylinder(d=M4_OD,h=Base_Ht + 2,$fn=M4_OD_Res);     //M4 Hole to Mount PS
            cylinder(d=M4Hd_OD,h=4,$fn=M4Hd_OD_Res);           //M4 Screw Head to Mount PS

            translate([0,0,3.99])
            cylinder(d1=M4Hd_OD,d2=M4_OD,h=1.5,$fn=M4_OD_Res); //M4 Screw Head to Mount PS
        }
        translate([-1,10,10])
        rotate([0,90,0])
        cylinder(d=M5_OD,h=20,$fn=M5_OD_Res);     //M5 T-Nut Mount Hole
        translate([6.5,10,10])
        rotate([0,90,0])
        cylinder(d1=M5Hd_OD,d2=M5Hd_OD + 1,h=.51,$fn=M5Hd_OD_Res);     //M5 Head T-Nut Mount Hole
//In case user adjust design, Allow for M5x12mm screw access
        translate([7,10,10])
        rotate([0,90,0])
//sphere does not come out same OD as cylinder, so hull it
        hull()
        {
            cylinder(d=M5Hd_OD + 1,h=13,$fn=M5Hd_OD_Res);
            translate([0,0,13])
            sphere(d=M5Hd_OD + 1,$fn=M5Hd_OD_Res);
        }
//Cutout some below PS mount
        translate([PS_X + PS_Wall_Wid2 - 6.15,PSB_Y + 9,-1])
        hull()
        {
            cylinder(d=6,h=10,$fn=24);
            translate([12.3,0,0])
            cylinder(d=6,h=10,$fn=24);
            translate([0,13.75,0])
            cylinder(d=6,h=10,$fn=24);
            translate([12.3,13.75,0])
            cylinder(d=6,h=10,$fn=24);
        }
        translate([-.002,50.48-9.2012,-1])
        cube([7.004,20,20]);
        translate([0,50.48-9.2012,-1])
        cylinder(d=7,h=20,$fn=4);

        translate([-1,41.28,10.22])
        rotate([36.73,0,0])
        cube([9,5,10]);

        translate([-1,-1,-10])
        cube([200,200,10]);
    }
}
if (Print_Type == 0)
{
    if (PowerCase_ON == 1)
    {
        DrawFrontMount();
    } else
    {
        DrawBackMount();
    }
    translate([PS_X + PS_Wid + PS_Wall_Thkx2+6,LenBack + PSB_Y,0])
    mirror([0,1,0])
    DrawBackMount();
} else
{
    if (Sphinx == 1)
    {
        translate([21.5,28 - 85.2 + (VSlot_Len / 2),166.13])
        rotate([0,90,0])
        rotate([0,0,90])
        color("silver",.5)
        %Sphinx_Y_Plate();
    }

    if (PowerCase_ON == 1)
    {
        rotate([-90,0,0])
        translate([VX_Offset,VY_Offset,0])
        color("silver",.7)
        %V_Slot(VSlot_Len);
    } else
    {
        rotate([-90,0,0])
        translate([VX_Offset,VY_Offset,0])
        color("silver",.7)
        %V_Slot(VSlot_Len+2);
    }
    if (PS_ON == 1)
    {
        if (PowerCase_ON == 1)
        {
            %PS_Case();
        } else
        {
            %PS();
        }
    }
    if (PowerCase_ON == 1)
    {
        DrawFrontMount();
        translate([0,PSF_Y + LenFront + 144 + (PowerCase_ON * 32) + PSB_Y,0])
        mirror([0,1,0])
        DrawBackMount();
    } else
    {
        DrawBackMount();
        translate([0,PSF_Y + LenFront + 144 + (PowerCase_ON * 32) + PSB_Y+2,0])
        mirror([0,1,0])
        DrawBackMount();
    }
}