//X/Y Limit Switch Holder & Cover for Sphinx CNC
//12/21/2018    By: David Bunch
//
//
Base_Thk = 6;
M5_OD = 5.8;            //Diameter of M5 holes
M25_OD = 2.7;           //M2.5 Diameter for Limit Switch Holes
M25Hd = 6.4;
W_Ht = 48;              //Height of Wire Cover (added 8mm more to clear spade connector)
echo(W_Ht = W_Ht);
module SpaceConnector()
{
    import("Spade_Connector.stl");
}
module LimitSwitch()
{
    color("red")
    import("LimitSwitch.stl", convexity=3);
    for (x = [1.5,9.5,18.25])
    {
        translate([x,12,3.5])
        rotate([90,0,0])
        rotate([0,0,90])
        color("blue",.5)
        %SpaceConnector();
    }
}
module M25HeadCut()
{
    rotate([0,90,0])
    translate([0,0,14])
    cylinder(d=6,h=5,$fn=24);

    rotate([0,90,0])
    cylinder(d=M25_OD,h=20,$fn=16);
}
module WireCoverCut()
{
    translate([0,0,-2-2])
    linear_extrude(height = W_Ht+2, center = false, convexity = 10)polygon(points = 
    [[70.5,39],[44.54,39],[44.54,38.98],[44.54,30.7],[70.5,30.7],
    [70.97,30.73],[71.42,30.8],[71.87,30.93],[72.3,31.11],[72.71,31.34],
    [73.09,31.61],[73.44,31.92],[73.75,32.26],[74.01,32.64],[74.24,33.05],
    [74.42,33.48],[74.55,33.93],[74.62,34.39],[74.65,34.85],[74.62,35.32],
    [74.55,35.77],[74.42,36.22],[74.24,36.65],[74.01,37.06],[73.75,37.44],
    [73.44,37.78],[73.09,38.1],[72.71,38.36],[72.3,38.59],[71.87,38.77],
    [71.42,38.9],[70.97,38.97]]);
}
module SideConnect()
{
    linear_extrude(height = W_Ht, center = false, convexity = 10)polygon(points = 
    [[70.5,41],[42.5,41],[41.98,40.93],[41.5,40.73],[41.09,40.41],
    [40.77,40],[40.57,39.52],[40.5,39],[40.5,30.7],[40.58,30.14],
    [40.82,29.62],[41.19,29.19],[41.67,28.88],[42.22,28.72],[72.69,28.72],
    [73,28.75],[73.49,28.86],[73.98,29.02],[74.43,29.24],[74.86,29.52],
    [75.26,29.84],[75.61,30.2],[75.92,30.61],[76.18,31.04],[76.38,31.51],
    [76.5,31.87],[76.58,32.25],[76.63,32.63],[76.65,33.01],[76.65,34.85],
    [76.61,35.54],[76.5,36.22],[76.31,36.88],[76.04,37.52],[75.71,38.12],
    [75.31,38.68],[74.85,39.2],[74.33,39.66],[73.77,40.06],[73.17,40.39],
    [72.53,40.66],[71.87,40.85],[71.19,40.96]]);
}
WS_Add = 18;        //Add this many mm's to length of wire slot (at least 14mm probably)
                    //This is needed to get spade connectors out
                    //Largest diameter of spade connector is 5.6mm
WC_ID = 15;          //Initially set to 6.3
WC_OD = WC_ID + 6;
WC_Rad = WC_OD / 2;
module WireSlot()
{
    union()
    {
        hull()
        {
            cylinder(d=WC_OD,h=8,$fn=40);
            translate([0,4.15+10,0])
            cylinder(d=WC_OD,h=8,$fn=40);
            translate([0,4.15+4+1+8,6+1])
            cylinder(d=WC_OD,h=1,$fn=40);

        translate([-WC_Rad,-WC_Rad,0])
        cube([WC_OD+3.8,WC_Rad,8+2]);       //Added 2mm to go beyond rounded corner
        }
    }
}
module WireSlotCut()
{
    translate([0,0,-1])
    hull()
    {
        cylinder(d=WC_ID,h=12,$fn=40);
        translate([0,4.15+10,0])
        cylinder(d=WC_ID,h=12,$fn=40);
    }

    translate([0,0,-.01])
    hull()
    {
        cylinder(d1=WC_ID+2,d2=WC_ID,h=1,$fn=40);
        translate([0,4.15+10,0])
        cylinder(d1=WC_ID+2,d2=WC_ID,h=1,$fn=40);
    }
    translate([0,0,8.01])
    hull()
    {
        cylinder(d1=WC_ID,d2=WC_ID+2,h=1,$fn=40);
        translate([0,4.15+10,0])
        cylinder(d1=WC_ID,d2=WC_ID+2,h=1,$fn=40);
    }
}
module TrapBase(T_Ht = 15)
{
    linear_extrude(height = T_Ht, center = false, convexity = 10)polygon(points = 
    [[-4.58,0],[-2.89,1.69],[2.89,1.69],[4.58,0]]);
}
module VMount()
{
    TB_Ht = 15;
    difference()
    {
        union()
        {
            hull()
            {
                cylinder(d=15,h=6,$fn=52);
                translate([-7.5,8.72+2,0])
                cube([15+14.5,.1,6]);
            }
            difference()
            {
        
                rotate([0,-90,0])
                rotate([0,0,90])
                translate([0,-.01,-7.5])
                union()
                {
                    TrapBase(TB_Ht);
                    translate([0,0,0])
                    hull()
                    {
                        TrapBase(.01);
                        translate([-4.58,0,-1.7])
                        cube([9.16,.01,.1]);
                    }
                }
                translate([0,0,-2])
                linear_extrude(height = 8, center = false, convexity = 10)polygon(points = 
                [[-7.5,0],[-8.5,0],[-8.5,-8.5],[10.2,-8.5],[10.2,-1.56],
                [9.2,-1.56],[4.97,-5.61],[4.26,-6.17],[3.49,-6.64],[2.66,-7.01],
                [1.8,-7.28],[0.9,-7.45],[0,-7.5],[-0.9,-7.45],[-1.8,-7.28],
                [-2.66,-7.01],[-3.49,-6.64],[-4.26,-6.17],[-4.97,-5.61],[-5.61,-4.97],
                [-6.17,-4.26],[-6.64,-3.49],[-7.01,-2.66],[-7.28,-1.8],[-7.45,-0.9]]);
            }
        }
        translate([0,0,-3])
        cylinder(d=M5_OD,h=12,$fn=24);
    }
}
module VerticalWelds()
{
    Weld_Ht = 24.8;
    translate([46.5,28.72,0])
    union()
    {
        cylinder(d=5,h=Weld_Ht,$fn=4);
        translate([0,0,Weld_Ht])
        cylinder(d1=5,d2=0,h=2.6,$fn=4);
    }
    translate([65.3,41,22.95])
    union()
    {
        cylinder(d=5,h=25.05,$fn=4);
        translate([0,0,-2.6])
        cylinder(d1=0,d2=5,h=2.6,$fn=4);
    }
}
module Draw_X_Limit_Holder()
{
    difference()
    {
        union()
        {
            SideConnect();
            translate([42.5+4.15+3.8+1.35+3,41+7,41.85-1.35-3])
            rotate([90,0,0])
            rotate([0,0,180])
            WireSlot();
            translate([40.5,20,7.5])
            mirror([0,0,1])
            rotate([0,90,0])
            VMount();
            VerticalWelds();
        }
        translate([42.5+4.15+3.8+1.35+3,41+7,41.85-1.35-3])
        rotate([90,0,0])
        rotate([0,0,180])
        WireSlotCut();
        translate([53.3,28.72-5,6.5])
        rotate([0,0,90])
        M25HeadCut();
        translate([62.9,28.72-5,6.5])
        rotate([0,0,90])
        M25HeadCut();
        WireCoverCut();         //Cut out Inside of Cover
    }
    translate([68.3,30.7,-1])
    rotate([0,0,180])
    rotate([90,0,0])
    %LimitSwitch();         //Show Switch Mounted in part
}
module Draw_Y_Limit_Holder()
{
        difference()
        {
            union()
            {
                SideConnect();
                translate([42.5+4.15+3.8+1.35+3,41+7,41.85-1.35-3])
                rotate([90,0,0])
                rotate([0,0,180])
                WireSlot();
                translate([40.5+14.5-14.5,20-1.5+1.5,15-7.5])
                mirror([0,0,1])
                rotate([0,90,0])
                VMount();
                VerticalWelds();
            }
            translate([42.5+4.15+3.8+1.35+3,41+7,41.85-1.35-3])
            rotate([90,0,0])
            rotate([0,0,180])
            WireSlotCut();
            translate([53.3,28.72-5,6.5])
            rotate([0,0,90])
            M25HeadCut();
            translate([62.9,28.72-5,6.5])
            rotate([0,0,90])
            M25HeadCut();
            WireCoverCut();         //Cut out Inside of Cover
        }
        translate([68.3,30.7,-1])
        rotate([0,0,180])
        rotate([90,0,0])
        %LimitSwitch();         //Show Switch Mounted in part
}
translate([-25,12,48])
rotate([180,0,0])
rotate([0,0,90])
translate([-40.5,-48,0])
Draw_X_Limit_Holder();
translate([-40.5,-48,31])
rotate([180,0,0])
mirror([0,1,0])
{
    translate([0,0,-17])
    Draw_Y_Limit_Holder();
}