//Z Limit Switch Holder & cover for Sphinx CNC
//12/21/2018    By: David Bunch
//
//Use 2-M2.5x12mm screws or 2-M2x12mm screws
//If needed, you can drill out holes with 7/64" drill bit

M5_OD = 5.8;            //Diameter of M5 holes
M25_OD = 2.7;           //M2.5 Diameter for Limit Switch Holes

W_Ht = 33;              //Height of Wire Cover (added 8mm more to clear spade connector)
W_Y1 = 20;
echo(W_Ht = W_Ht);
module TopCover()
{
    import("Z_ReductionPlateCover_Sphinx_Rev16.stl");
}
module SpaceConnector()
{
    import("Spade_Connector.stl");
}
module Nema_ReductionPlate()
{
    import("NEMA23_ReductionPlate_C-Beam.stl");
    translate([0,0,6])
    color("green",.5)
    %TopCover();
}
module CB_mount()
{
    import("C-Beam_End_Mount.stl");
}
module LimitSwitch()
{
    color("red")
    import("LimitSwitch.stl", convexity=3);
    for (x = [1.5,9.5,18.25])
    {
        translate([x,12,3.5])
        rotate([90,0,0])
        rotate([0,0,90])
        color("blue",.5)
        %SpaceConnector();
    }
}
module WireSlot()
{
    union()
    {
        hull()
        {
            cylinder(d=12.3,h=8,$fn=40);
            translate([0,W_Y1,0])
            cylinder(d=12.3,h=8,$fn=40);
            translate([0,W_Y1+4+1,6+1])
            cylinder(d=12.3,h=1,$fn=40);
        }
        translate([-6.15,-10.15,])
        cube([12.3,10.15,8]);
    }
}
module WireSlotCut()
{
        translate([9.95+7.5-1.5,7,17.85+5.9])
        rotate([90,0,0])
        rotate([0,0,180])
        hull()
        {
            cylinder(d=6.3,h=10,$fn=40);
            translate([0,W_Y1,0])
            cylinder(d=6.3,h=10,$fn=40);
        }
        translate([9.95+7.5-1.5,6.01,17.85+5.9])
        rotate([90,0,0])
        rotate([0,0,180])
        hull()
        {
            cylinder(d1=8.3,d2=6.3,h=1,$fn=40);
            translate([0,W_Y1,0])
            cylinder(d1=8.3,d2=6.3,h=1,$fn=40);
        }
        translate([9.95+7.5-1.5,-1.01,17.85+5.9])
        rotate([90,0,0])
        rotate([0,0,180])
        hull()
        {
            cylinder(d1=6.3,d2=8.3,h=1,$fn=40);
            translate([0,W_Y1,0])
            cylinder(d1=6.3,d2=8.3,h=1,$fn=40);
        }
}
module WireCoverCut()
{
    union()
    {
        translate([2,0,0])
        cube([8.3,28,48-6]);
        translate([6.15,0,0])
        cylinder(d=8.3,h=48-6,$fn=56);
    }
}
module TopFlat()
{
    linear_extrude(height = 2, center = false, convexity = 10)polygon(points = 
    [[-5.85,-36.13],[11.77,-36.15],[11.8,0],[5.49,0],[4.56,0.13],
    [3.84,0.15],[3.15,-0.01],[2.5,-0.32],[1.96,-0.78],[1.53,-1.35],
    [1.25,-2.01],[1.14,-2.72],[1.2,-3.43],[1.42,-4.11],[1.79,-4.71],
    [2.08,-5.07],[3.52,-8.23],[3.52,-11.71],[2.08,-14.87],[-8.44,-31.38],
    [-8.66,-31.8],[-8.82,-32.24],[-8.91,-32.7],[-8.93,-33.17],[-8.87,-33.64],
    [-8.75,-34.1],[-8.55,-34.53],[-8.3,-34.92],[-7.98,-35.27],[-7.62,-35.57],
    [-7.21,-35.81],[-6.78,-35.99],[-6.32,-36.1]]);
}
module SideConnect()
{
    linear_extrude(height = 48, center = false, convexity = 10)polygon(points = 
    [[-5.85,-29.97],[-6.36,-30.01],[-6.85,-30.14],[-7.32,-30.35],[-7.75,-30.63],
    [-8.12,-30.98],[-8.44,-31.38],[-8.66,-31.8],[-8.82,-32.24],[-8.91,-32.7],
    [-8.93,-33.17],[-8.87,-33.64],[-8.75,-34.1],[-8.55,-34.53],[-8.3,-34.92],
    [-7.98,-35.27],[-7.62,-35.57],[-7.21,-35.81],[-6.78,-35.99],[-6.32,-36.1],
    [-5.85,-36.13],[15.95,-36.15],[16.64,-36.11],[17.32,-36],[17.98,-35.81],
    [18.62,-35.54],[19.22,-35.21],[19.78,-34.81],[20.3,-34.35],[20.76,-33.83],
    [21.16,-33.27],[21.49,-32.67],[21.76,-32.03],[21.95,-31.37],[22.06,-30.69],
    [22.1,-30],[22.1,-2],[22.03,-1.48],[21.83,-1],[21.51,-0.59],
    [21.1,-0.27],[20.62,-0.07],[20.1,0],[11.8,0],[11.24,-0.08],
    [10.72,-0.32],[10.29,-0.69],[9.98,-1.17],[9.82,-1.72],[9.82,-2.29],
    [9.87,-2.76],[9.87,-3.23],[9.83,-3.69],[9.74,-4.16],[9.61,-4.61],
    [9.44,-5.05],[9.23,-5.46],[8.98,-5.86],[8.69,-6.24],[8.37,-6.58],
    [8.02,-6.89],[7.64,-7.17],[7.23,-7.41],[6.81,-7.61],[6.44,-7.81],
    [6.12,-8.08],[5.85,-8.41],[5.65,-8.78],[5.53,-9.18],[5.49,-9.6],
    [5.49,-29.97],[-5.75,-29.97]]);
}
module Draw_X_Limit_Holder()
{
    difference()
    {
        union()
        {
            translate([-1.5,0,-(W_Ht-19)])
            {
                translate([9.95+7.5,5.99,W_Ht-1.15+6])
                rotate([90,0,0])
                rotate([0,0,180])
                WireSlot();
            }
            translate([0,0,32])
            TopFlat();
            translate([0,0,-14])
            SideConnect();
            translate([9.82,-7.29,-14])
            cube([12.28,5.57,48]);      //Fill in gap of curve
        }
        translate([1.5,-25.97,31])
        cylinder(d=M5_OD,h=4,$fn=24);
        WireSlotCut();

//Allen Wrench Access Holes
        translate([0,0,-(W_Ht-19)])
        {
            translate([20-1.5,-12.8,7.5])
            rotate([0,90,0])
            cylinder(d=6,h=5,$fn=24);
            translate([20-1.5,-22.4,7.5])
            rotate([0,90,0])
            cylinder(d=6,h=5,$fn=24);
//Limit Switch Holes
            translate([-1.5,-12.8,7.5])
            rotate([0,90,0])
            cylinder(d=M25_OD,h=20,$fn=16);
            translate([-1.5,-22.4,7.5])
            rotate([0,90,0])
            cylinder(d=M25_OD,h=20,$fn=16);
            translate([7.5+3.8-1.5,-30,-.1])
            WireCoverCut();         //Cut out Inside of Cover
        }
//Chamfer bottom front
        translate([-10,-36.15,34])
        scale([1,1,4])
        rotate([0,90,0])
        cylinder(d=4,h=40,$fn=4);
        translate([22.1,6,34])
        scale([1,1,2])
        rotate([90,0,0])
        cylinder(d=8,h=50,$fn=4);

        translate([18,3-32.05,29.9])
        rotate([0,0,-45])
        rotate([0,60,0])
        translate([0,0,3])
        cylinder(d=40,h=50,$fn=12);

        translate([9.8,5.99,0])
        cylinder(d=2,h=60,$fn=4);
        translate([22.1,5.99,0])
        cylinder(d=2,h=60,$fn=4);

        translate([-9.93,-37.1,-15])
        cube([15.42,8.13,24]);
//Begin chamfering some edges for less plastic less sharp corners
        translate([-8.93,-37.1,-15+24])
        rotate([-90,0,0])
        cylinder(d=6,h=12,$fn=4);
        translate([-9.93,-37.1,-15+24])
        rotate([0,90,0])
        cylinder(d=6,h=15.42,$fn=4);
        translate([-9.93+15.42,-37.1,-15])
        {
            cylinder(d=6,h=24,$fn=4);
            translate([0,0,24])
            cylinder(d1=6,d2=0,h=3,$fn=4);
        }
        hull()
        {
            translate([5.49,-36.14,9-4.33])
            rotate([90,0,0])
            cylinder(d=8.66,h=100,center=true,$fn=4);
            translate([5.49,-36.14,-15])
            rotate([90,0,0])
            cylinder(d=8.66,h=100,center=true,$fn=4);
        }
        translate([9.82,-36.13,-15])
        cylinder(d=7.13,h=19.69,$fn=4);

        translate([6.76,-39.19,9-4.33])
        rotate([0,0,45])
        scale([1,1,1.04])
        translate([2.5,0,0])
        rotate([90,0,0])
        cylinder(d=8.66,h=8.9,center=true,$fn=4);
    }
    translate([13.3-1.5+6.5,-27.8+20.5,-(W_Ht-19)])
    rotate([0,0,-90])
    rotate([90,0,0])
    %LimitSwitch();         //Show Switch Mounted in part
}
translate([0,0,34])
rotate([0,180,0])
{
    translate([-40+5.5,17.6-30,12])
    {
        %CB_mount();
        translate([0,0,12])
        %Nema_ReductionPlate();
    }
    Draw_X_Limit_Holder();
}